# Requires gnuplot >= 4.6
load "common.plot"
# Remove default border from common.plot and leave only the left one.
unset border
set border 2 lc rgb BorderColor # 15 = 1 + 2 + 4 + 8 = bottom + left + top + right

set bmargin 3 # Number of characters (It's 1 + the number of lines for the terminal default font).

set ylabel "Dynamic data block transfers optimization" font TitleFont
set yrange[-5:100]
set grid ytics lt -1 lc rgb GridColor
set format y "%.0f%%"

# xtics without labels. I put the marks outwards (so they are not inside the boxes, which are transparent) and also
# ask for their scale to be 0 (major) and 0 (minor). The labels will be read from the file
set xtics out scale 0, 0 center nomirror textcolor lt 0 font TicksFont

set ytics out nomirror textcolor lt "#000000" font TicksFont
set key on inside right top vertical Right noreverse enhanced autotitles samplen 2 height -0.3 font KeyFont

set datafile separator ";"
set style fill solid 1.0 border -1 # "border -1" to draw it in black.
set style data histograms
set style histogram gap 1	# Used to center the xtics with the bars, if they are uncentered.
bw = 1.0
set boxwidth bw

###################### Plot
set output 'DMA_DMM1_Improvements.pdf'

# x:y:color:xticlabel. Alternativa: x:y:ancho:color
# Etiquetas: x:y:text. In histogram, $0 is the center of the current set of bars.
lo = 2	# labelOffset (vertical)
MakeLabel(x) = sprintf("%0.2f %%", x)
CalcYPos(y) = (y >= 0) ? (y + lo) : (y - lo)
plot 'DMA_DMM1_Improvements.data' \
	   using ($2) title 'DMM1-Opt vs. NoDMA' lt rgb Cyan,\
		'' using ($0-0.3):(CalcYPos($2)):(MakeLabel($2)) with labels notitle left font LabelFont,\
	'' using ($3):xtic(1) title 'DMM1-Opt vs. DMABad' lt rgb PureGreen,\
		'' using ($0+0.05):($3 + lo):(MakeLabel($3)) with labels notitle left font LabelFont,\
	0 notitle lt 1 lw 2 lc rgb "#000000"	# Plot a line for y=0. It's not done by default.
