# Requires gnuplot >= 4.6
load "common.plot"

set bmargin 2 # Number of characters (It's 1 + the number of lines for the terminal default font).

set ylabel "Total memory footprint (MB)" font TitleFont offset 1	# Move title closer to axis
set yrange[0:*]
set grid ytics lt -1 lc rgb GridColor
set format y "%2.0f"
set rmargin 0.5	# Maximize graph area
set lmargin 6

# xtics without labels. I put the marks outwards (so they are not inside the boxes, which are transparent) and also
# ask for their scale to be 0 (major) and 0 (minor). The labels will be read from the file
set xtics out scale 0, 0 center nomirror textcolor lt 0 font TicksFont

set ytics out nomirror 0, 5 textcolor lt "#000000" font TicksFont # Number are <start, step, [end]>. End is open to match range *
set key on inside right top vertical Right noreverse enhanced autotitles samplen 2 height -0.3 font KeyFont

set datafile separator ";"
set style fill solid 1.0 border -1 # "border -1" to draw it in black.
set style data histograms
set style histogram gap 3	# Used to center the xtics with the bars, if they are uncentered.
bw = 1.0
set boxwidth bw

###################### Plot
set output 'Footprint_TotalAllInputsAllDMM.pdf'

# x:y:color:xticlabel. Alternativa: x:y:ancho:color
# Etiquetas: x:y:text. In histogram, $0 is the center of the current set of bars.
lo = 1	# labelOffset (vertical)
bw = 0.8
numBars = 9	# For some reason, instead of 3 (maybe the same that gap has to be 1?)
MakeLabel(x) = sprintf("%0.2f", x/1e6)
#plot 'Footprint_TotalAllInputsAllDMM.data' \
#	   using ($2/1e6):xtic(1) title 'DMM 1' lt rgb Cyan,	'' using ($0-bw*4/numBars):($2/1e6 + lo):(MakeLabel($2)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($3/1e6) title 'DMM 2' lt rgb PureGreen,		'' using ($0-bw*3/numBars):($3/1e6 + lo):(MakeLabel($3)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($4/1e6) title 'DMM 3' lt rgb Yellow,			'' using ($0-bw*2/numBars):($4/1e6 + lo):(MakeLabel($4)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($5/1e6) title 'DMM 4' lt rgb PureBlue,		'' using ($0-bw*1/numBars):($5/1e6 + lo):(MakeLabel($5)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($6/1e6) title 'DMM 5' lt rgb PureRed,			'' using ($0):($6/1e6 + lo):(MakeLabel($6)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($7/1e6) title 'DMM 6' lt rgb LightRed,		'' using ($0+bw*1/numBars):($7/1e6 + lo):(MakeLabel($7)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($8/1e6) title 'DMM 7' lt rgb Granate,			'' using ($0+bw*2/numBars):($8/1e6 + lo):(MakeLabel($8)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($9/1e6) title 'DMM 8' lt rgb PureCyan,		'' using ($0+bw*3/numBars):($9/1e6 + lo):(MakeLabel($9)) with labels notitle rotate by 90 left font VerySmallLabelFont,\
#	'' using ($10/1e6) title 'DMM 9' lt rgb Orange,			'' using ($0+bw*4/numBars):($10/1e6 + lo):(MakeLabel($10)) with labels notitle rotate by 90 left font VerySmallLabelFont

plot 'Footprint_TotalAllInputsAllDMM.data' \
	   using ($2/1e6):xtic(1) title 'DMM 1' lt rgb Cyan,\
	'' using ($3/1e6) title 'DMM 2' lt rgb PureGreen,\
	'' using ($4/1e6) title 'DMM 3' lt rgb Yellow,\
	'' using ($5/1e6) title 'DMM 4' lt rgb PureBlue,\
	'' using ($6/1e6) title 'DMM 5' lt rgb PureRed,\
	'' using ($7/1e6) title 'DMM 6' lt rgb LightRed,\
	'' using ($8/1e6) title 'DMM 7' lt rgb Granate,\
	'' using ($9/1e6) title 'DMM 8' lt rgb PureCyan,\
	'' using ($10/1e6) title 'DMM 9' lt rgb Orange
