# Requires gnuplot >= 4.6
load "common.plot"

################################
# Configure multiplot for broken axes.
y1 = 0.0; y2 = 400; y3 = 3500; y4 = 5000
factor = 0.5 # relative height of bottom plot
gap = 0.04 # Gap between low and upper parts. Percentage in graph size.
size = (1.0 - gap*2) # Factor, 1.0 = total figure height. I multiply gap * 2 to leave a bit of empty space at the top (alternatively, use tmargin)

################################
set output 'TotalMemoryAccessesPerInput.pdf'
set bmargin 2 # Number of characters (It's 1 + the number of lines for the terminal default font).
set multiplot

###################### Plot empty graph to set the y labels full size
set yrange[y1:y4]
set ylabel "Total memory accesses" font TitleFont offset -1
set label 1 "(Millions)" at graph -0.007, 0.5 center rotate by 90 front font Title2Font
unset tics
unset border
unset key
plot 1/0 with points	# Plot something out of range for the labels to be actually drawn in the multiplot
unset ylabel
unset label 1

###################### Set up rest of the graph
set border 3 lc rgb "#000000" # 15 = 1 + 2 + 4 + 8 = bottom + left + top + right
set lmargin 10.5
set rmargin 0.5
set grid ytics lt -1 lc rgb GridColor
set format y "%4.0f"

# xtics without labels. I put the marks outwards (so they are not inside the boxes, which are transparent) and also
# ask for their scale to be 0 (major) and 0 (minor). The labels will be read from the file
set xtics out scale 0, 0 center nomirror textcolor lt 0 font TicksFont

set ytics out nomirror textcolor lt "#000000" font TicksFont
set key on inside right top vertical Right noreverse enhanced autotitles samplen 2 height -0.3 font KeyFont

set datafile separator ";"
set style fill solid 1.0 border -1 # "border -1" to draw it in black.
set style data histograms
set style histogram gap 1	# Used to center the xtics with the bars, if they are uncentered.
set boxwidth 1.0

###################### Plot lower part
set tmargin at screen size * factor
set yrange[y1:y2]
unset key

#axes broken lines
set arrow 1 from -1.13,407 to -0.97,432 nohead front
set arrow 2 from -1.03,407 to -0.87,432 nohead front

# x:y:color:xticlabel. Alternativa: x:y:ancho:color
# Etiquetas: x:y:text
plot 'TotalMemoryAccessesPerInput.data' \
	   using ( ($2/1e6) ) title 'DMM 1' lt rgb Cyan,\
	'' using ($3/1e6) title 'DMM 6' lt rgb PureGreen,\
	'' using ($4/1e6):xtic(1) title "DMM 7" lt rgb Yellow

unset arrow 1; unset arrow 2

###################### Plot upper part
unset xtics
unset xlabel
set key
set border 2 lc rgb "#000000" # 15 = 1 + 2 + 4 + 8 = bottom + left + top + right
set bmargin at screen size * factor + gap
set tmargin at screen size + gap
set yrange[y3:y4]
# x:y:color:xticlabel. Alternativa: x:y:ancho:color
# Etiquetas: x:y:text
plot 'TotalMemoryAccessesPerInput.data' \
	   using ( ($2/1e6) ) title 'DMM 1' lt rgb Cyan,\
	'' using ($3/1e6) title 'DMM 6' lt rgb PureGreen,\
	'' using ($4/1e6):xtic(1) title "DMM 7" lt rgb Yellow

unset multiplot
