# Requires gnuplot >= 4.6
load "common.plot"

set bmargin 2 # Number of characters (It's 1 + the number of lines for the terminal default font).

set ylabel "Weight of DMM on total memory accesses" font TitleFont
set yrange[0:100 < *]
set grid ytics lt -1 lc rgb GridColor
set format y "%.0f%%"

# xtics without labels. I put the marks outwards (so they are not inside the boxes, which are transparent) and also
# ask for their scale to be 0 (major) and 0 (minor). The labels will be read from the file
set xtics out scale 0, 0 center nomirror textcolor lt 0 font TicksFont

set ytics out nomirror textcolor lt "#000000" font TicksFont
set key on inside right top vertical Right noreverse enhanced autotitles samplen 2 height -0.3 font KeyFont

set datafile separator ";"
set style fill solid 1.0 border -1 # "border -1" to draw it in black.
set style data histograms
set style histogram gap 1	# Used to center the xtics with the bars, if they are uncentered.
bw = 1.0
set boxwidth bw

###################### Plot
set output 'WeightOfDMMOnTotalMemoryAccessesPerInput.pdf'

# x:y:color:xticlabel. Alternativa: x:y:ancho:color
# Etiquetas: x:y:text. In histogram, $0 is the center of the current set of bars.
lo = 1	# labelOffset (vertical)
numBars = 4	# For some reason, instead of 3 (maybe the same that gap has to be 1?)
MakeLabel(x) = sprintf("%0.2f%%", x)
plot 'WeightOfDMMOnTotalMemoryAccessesPerInput.data' \
	   using ($2) title 'DMM 1' lt rgb Cyan, 			'' using ($0-bw/numBars):($2 + lo):(MakeLabel($2)) with labels notitle rotate by 90 left font LabelFont,\
	'' using ($3) title 'DMM 6' lt rgb PureGreen, 		'' using ($0):($3 + lo):(MakeLabel($3)) with labels notitle rotate by 90 left font LabelFont,\
	'' using ($4):xtic(1) title "DMM 7" lt rgb Yellow,	'' using ($0+bw/numBars):($4 + lo):(MakeLabel($4)) with labels notitle rotate by 90 left font LabelFont
